process.mixin(require("./common"));

// üäö

puts("Σὲ γνωρίζω ἀπὸ τὴν κόψη");

assertTrue( /Hellö Wörld/.test("Hellö Wörld") );

